<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.cpp" line="36"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../AboutDialog.cpp" line="54"/>
        <source>Version %1.%2.%3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AboutDialog.cpp" line="63"/>
        <source>Licensed under the GPLv3</source>
        <translation>Lizensiert unter der GPLv3</translation>
    </message>
</context>
<context>
    <name>ChatBox</name>
    <message>
        <location filename="../ChatBox.cpp" line="50"/>
        <source>Chat</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CreateGameDialog</name>
    <message>
        <location filename="../CreateGameDialog.cpp" line="34"/>
        <source>Create game</source>
        <translation>Spiel erstellen</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="45"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="47"/>
        <source>Game name</source>
        <translation>Spielname</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="51"/>
        <source>Game type</source>
        <translation>Spieltyp</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="57"/>
        <source>Game mode</source>
        <translation>Spielmodus</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="71"/>
        <source>Players</source>
        <translation>Spieler</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="73"/>
        <source>Max. players</source>
        <translation>Max. Spieler</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="80"/>
        <source>Timeout</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="87"/>
        <source>Initial stake</source>
        <translation>Anfänglicher Einsatz</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="104"/>
        <source>Blinds</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="106"/>
        <source>Starting blinds</source>
        <translation>Anfängliche blinds</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="113"/>
        <source>Raise factor</source>
        <translation>Erhöhungsfaktor</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="121"/>
        <source>Raise time</source>
        <translation>Erhöhungszeit</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="138"/>
        <source>Private game</source>
        <translation>Privates Spiel</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="140"/>
        <source>Password protected</source>
        <translation>passwortgeschützt</translation>
    </message>
    <message>
        <location filename="../CreateGameDialog.cpp" line="144"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
</context>
<context>
    <name>GameListTableModel</name>
    <message>
        <location filename="../GameListTableModel.cpp" line="33"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../GameListTableModel.cpp" line="34"/>
        <source>Gametype</source>
        <translation>Spieltyp</translation>
    </message>
    <message>
        <location filename="../GameListTableModel.cpp" line="35"/>
        <source>Players</source>
        <translation>Spieler</translation>
    </message>
    <message>
        <location filename="../GameListTableModel.cpp" line="36"/>
        <source>State</source>
        <translation>Status</translation>
    </message>
</context>
<context>
    <name>PClient</name>
    <message>
        <location filename="../pclient.cpp" line="1000"/>
        <source>Connecting...</source>
        <translation>Verbinde...</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="1306"/>
        <source>Connection closed.</source>
        <translation>Verbindung geschlossen.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="1285"/>
        <source>Connected.</source>
        <translation>Verbunden.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="63"/>
        <source>Server running version %1.%2.%3. Your client ID is %4.</source>
        <translation>Auf dem Server läuft Version %1.%2.%3. Deine Client-ID ist %4.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="82"/>
        <location filename="../pclient.cpp" line="118"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="83"/>
        <source>The version of the server isn&apos;t compatible anymore with this client version. Please either use an older client version or request the server admin to update the server version.</source>
        <translation>Die Version des Servers ist nicht mehr kompatibel mit dieser Client-Version. Bitte benutze entweder einen älteren Client, oder frage beim Server-Admin bezüglich eines Server Updates nach.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="360"/>
        <source>Game (%1) has been started.</source>
        <translation>Spiel (%1) wurde gestartet.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="367"/>
        <source>Game (%1) has been ended.</source>
        <translation>Spiel (%1) wurde beendet.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="381"/>
        <source>A new hand (#%1) begins.</source>
        <translation>Eine neue Hand (#%1) beginnt.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="393"/>
        <source>Blinds are now at %1/%2.</source>
        <translation>Blinds sind nun bei %1/%2.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="408"/>
        <source>Player %1 broke.</source>
        <translation>Spieler %1 ist ausgeschieden.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="437"/>
        <source>Your hole cards: [%1 %2].</source>
        <translation>Deine Holecards: [%1 %2].</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="463"/>
        <source>The flop: [%1 %2 %3].</source>
        <translation>Der Flop: [%1 %2 %3].</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="469"/>
        <source>The turn: [%1].</source>
        <translation>Der Turn: [%1].</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="473"/>
        <source>The river: [%1].</source>
        <translation>Der River: [%1].</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="503"/>
        <source>%1 was folded.</source>
        <translation>%1 wurde gefoldet.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="505"/>
        <source>%1 folded.</source>
        <translation>%1 foldet.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="512"/>
        <source>%1 was checked.</source>
        <translation>%1 wurde gecheckt.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="514"/>
        <source>%1 checked.</source>
        <translation>%1 checkt.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="529"/>
        <source>%1 called %2.</source>
        <translation>%1 callt %2.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="537"/>
        <source>%1 bet to %2.</source>
        <translation>%1 setzt auf %2.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="543"/>
        <source>%1 raised to %2.</source>
        <translation>%1 erhöht auf %2.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="549"/>
        <source>%1 is allin with %2.</source>
        <translation>%1 ist Allin mit %2.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="588"/>
        <source>%1 shows %2.</source>
        <translation>%1 zeigt %2.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="601"/>
        <source>%2 (%1) joined foyer.</source>
        <translation>%2 (%1) betritt das Foyer.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="607"/>
        <source>%2 (%1) left foyer.</source>
        <translation>%2 (%1) verlässt das Foyer.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="646"/>
        <source>%1, it&apos;s your turn!</source>
        <translation>%1, du bist dran!</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="666"/>
        <source>%1 wins pot #%2 with %3.</source>
        <translation>%1 gewinnt Pot #%2 mit %3.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="671"/>
        <source>%1 receives %3 odd chips of split pot #%2.</source>
        <translation>%1 erhält %3 unteilbare Chips aus Split pot #%2.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="888"/>
        <source>Protocol error. The remote host does not seem to be a HoldingNuts server.</source>
        <translation>Protokollfehler. Die Gegenstelle scheint kein HoldingNuts Server zu sein.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="1274"/>
        <source>Connection error: %1.</source>
        <translation>Verbindungsfehler: %1.</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="74"/>
        <source>There is a newer version of HoldingNuts available (at least %1.%2.%3)</source>
        <translation>Es gibt eine neuere Version von HoldingNuts (mindestens %1.%2.%3)</translation>
    </message>
    <message>
        <location filename="../pclient.cpp" line="119"/>
        <source>The version of this client isn&apos;t compatible anymore with the server. Please download a recent version.</source>
        <translation>Die Version dieses Clients ist nicht mehr kompatibel zum Server. Bitte lade eine aktuelle Version herunter.</translation>
    </message>
</context>
<context>
    <name>PlayerListTableModel</name>
    <message>
        <location filename="../PlayerListTableModel.cpp" line="32"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
</context>
<context>
    <name>Seat</name>
    <message>
        <location filename="../Seat.cpp" line="77"/>
        <source>Location: %1</source>
        <translation>Standort: %1</translation>
    </message>
    <message>
        <location filename="../Seat.cpp" line="74"/>
        <source>Name: %1</source>
        <translation>Name: %1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../SettingsDialog.cpp" line="34"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="45"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="47"/>
        <source>Appearance</source>
        <translation>Aussehen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="136"/>
        <source>Player name</source>
        <translation>Spielername</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="124"/>
        <source>UUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="46"/>
        <source>Player info</source>
        <translation>Spielerinfo</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="173"/>
        <source>Bring window to top</source>
        <translation>Fenster nach vorne bringen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="194"/>
        <source>Display time in foyer chat</source>
        <translation>Zeit im Foyer-Chat anzeigen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="197"/>
        <source>Display join/left messages</source>
        <translation>Betritt/Verlässt Nachrichten anzeigen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="200"/>
        <source>Display game states</source>
        <translation>Spielaktionen anzeigen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="203"/>
        <location filename="../SettingsDialog.cpp" line="213"/>
        <source>Display player chat</source>
        <translation>Spieler-Chat anzeigen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="207"/>
        <source>Display player actions</source>
        <translation>Spieler-Aktionen anzeigen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="210"/>
        <source>Display hole/community cards</source>
        <translation>Hole-/Community-Cards anzeigen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="217"/>
        <source>Log to file</source>
        <translation>Log in Datei</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="218"/>
        <source>Foyer chat verbosity</source>
        <translation>Foyer-Chat Ausführlichkeit</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="222"/>
        <source>Table chat verbosity</source>
        <translation>Tisch-Chat Ausführlichkeit</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="122"/>
        <source>Locale</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="48"/>
        <source>Log and chat</source>
        <translation>Log und Chat</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="71"/>
        <source>Auto-Detect</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="109"/>
        <source>clear</source>
        <translation>löschen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="137"/>
        <source>Location</source>
        <translation>Standort</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="171"/>
        <source>Show strength of hand</source>
        <translation>Handstärke anzeigen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="123"/>
        <source>Sounds</source>
        <translation>Klänge</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="92"/>
        <source>only on focus</source>
        <translation>nur bei Fokus</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="90"/>
        <location filename="../SettingsDialog.cpp" line="181"/>
        <source>enabled</source>
        <translation>aktiviert</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="172"/>
        <source>Centralized table view</source>
        <translation>Zentrische Tischansicht</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="174"/>
        <source>Card deck</source>
        <translation>Kartendeck</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="158"/>
        <source>Default</source>
        <translation>Voreinstellung</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="159"/>
        <source>Classic</source>
        <translation>Klassisch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="183"/>
        <source>log chat</source>
        <translation>Chat loggen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.cpp" line="106"/>
        <source>generate</source>
        <translation>generieren</translation>
    </message>
</context>
<context>
    <name>WMain</name>
    <message>
        <location filename="../WMain.cpp" line="644"/>
        <source>Error connecting.</source>
        <translation>Fehler beim Verbinden.</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="73"/>
        <source>HoldingNuts Foyer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="466"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="255"/>
        <source>&amp;Connect</source>
        <translation>&amp;Verbinden</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="259"/>
        <source>Cl&amp;ose</source>
        <translation>&amp;Trennen</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="187"/>
        <source>&amp;Register</source>
        <translation>&amp;Anmelden</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="191"/>
        <source>&amp;Unregister</source>
        <translation>A&amp;bmelden</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="232"/>
        <source>Game ID</source>
        <translation>Spiel ID</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="234"/>
        <source>Initial stakes</source>
        <translation>Anfänglicher Einsatz</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="335"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="366"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="372"/>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="879"/>
        <source>THNL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="989"/>
        <source>Logout</source>
        <translation>Ausloggen</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="993"/>
        <source>Welcome</source>
        <translation>Willkommen</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="336"/>
        <source>CTRL+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="367"/>
        <source>CTRL+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="343"/>
        <source>&amp;Test</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="344"/>
        <source>CTRL+T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="263"/>
        <source>Server:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="149"/>
        <source>hide started</source>
        <translation>verstecke gestartete</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="152"/>
        <source>hide private</source>
        <translation>verstecke private</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="195"/>
        <source>&amp;Open table</source>
        <translation>Tisch &amp;öffnen</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="199"/>
        <source>&amp;Start game</source>
        <translation>&amp;Spiel starten</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="236"/>
        <source>Player timeout</source>
        <translation>Spieler timeout</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="238"/>
        <source>Blinds</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="286"/>
        <source>Create own game</source>
        <translation>Eigenes Spiel erstellen</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="351"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="352"/>
        <source>CTRL+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="408"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="409"/>
        <source>Connections</source>
        <translation>Verbindungen</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="693"/>
        <source>Private game</source>
        <translation>Privates Spiel</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="694"/>
        <source>Please enter the game password:</source>
        <translation>Bitte gib das Spielpasswort ein:</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="734"/>
        <source>The table will be opened on the next hand.</source>
        <translation>Der Tisch wird mit der nächsten Hand geöffnet.</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="881"/>
        <source>unkown gametype</source>
        <translation>unbekannter Spieltyp</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="890"/>
        <source>Cash game</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="892"/>
        <source>Tournament</source>
        <translation>Tunier</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="894"/>
        <source>Sit&apos;n&apos;Go</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="896"/>
        <source>unkown gamemode</source>
        <translation>unbekannter Spielmodus</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="905"/>
        <source>Waiting</source>
        <translation>Wartend</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="907"/>
        <source>Started</source>
        <translation>Gestartet</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="909"/>
        <source>Ended</source>
        <translation>Beendet</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="911"/>
        <source>unkown gamestate</source>
        <translation>unbekannter Spielstatus</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="252"/>
        <source>The desired server (domain-name or IP) to connect with.
You can optionally specify a port number.
Format: &lt;host&gt;[:&lt;port&gt;]</source>
        <translation>Der gewünschte Server (Domain-Name oder IP) mit dem verbunden werden soll.
Du kannst optional eine Port-Nummer angeben.
Format: &lt;host&gt;[:&lt;port&gt;]</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="359"/>
        <source>&amp;Handbook</source>
        <translation>&amp;Handbuch</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="360"/>
        <source>CTRL+H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="373"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../WMain.cpp" line="775"/>
        <source>You may need to restart the client for all settings to take effect.</source>
        <translation>Du musst den Client eventuell neustarten, damit alle Einstellungen übernommen werden.</translation>
    </message>
</context>
<context>
    <name>WTable</name>
    <message>
        <location filename="../WTable.cpp" line="823"/>
        <source>Fold</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="500"/>
        <source>HoldingNuts table</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="833"/>
        <source>Check</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="832"/>
        <source>Check/Fold</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1583"/>
        <source>Saved screenshot: %1.</source>
        <translation>Screenshot gespeichert: %1.</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1585"/>
        <source>Unable to save screenshot in %1.</source>
        <translation>Screenshot konnte nicht in %1 gespeichert werden.</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="318"/>
        <source>&amp;Fold</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="330"/>
        <source>&amp;Show</source>
        <translation>&amp;Zeigen</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="333"/>
        <source>&amp;Muck</source>
        <translation>&amp;Verdecken</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="336"/>
        <source>I&apos;m bac&amp;k</source>
        <translation>Bin zurüc&amp;k</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="340"/>
        <source>Sit&amp;out</source>
        <translation>Ausset&amp;zen</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="349"/>
        <source>Min</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="353"/>
        <source>1/4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="357"/>
        <source>1/2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="361"/>
        <source>3/4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="365"/>
        <source>Pot</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="462"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="465"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="468"/>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="471"/>
        <source>Ctrl+R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="474"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="478"/>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="481"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="484"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="487"/>
        <source>Ctrl+K</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="741"/>
        <source>&amp;Call %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="742"/>
        <location filename="../WTable.cpp" line="753"/>
        <source>&amp;Raise %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="760"/>
        <source>&amp;Bet %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="774"/>
        <location filename="../WTable.cpp" line="785"/>
        <source>&amp;Allin %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="826"/>
        <source>Allin %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="828"/>
        <source>Call %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="749"/>
        <source>&amp;Check</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="369"/>
        <source>Allin</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="998"/>
        <source>Main pot: %1</source>
        <translation>Haupt-Pot: %1</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1002"/>
        <source>Side pot %1: %2</source>
        <translation>Side-Pot: %1: %2</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1499"/>
        <source>%1, it&apos;s your turn!</source>
        <translation>%1, du bist dran!</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1526"/>
        <source>%1, you have %2 seconds left to respond!</source>
        <translation>%1, du hast %2 Sekunden verbleibend zu reagieren!</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1609"/>
        <source>Spades</source>
        <translation>Pik</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1610"/>
        <source>Hearts</source>
        <translation>Herz</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1611"/>
        <source>Diamonds</source>
        <translation>Karo</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1612"/>
        <source>Clubs</source>
        <translation>Kreuz</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1624"/>
        <source>Deuce</source>
        <translation>Zwei</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1624"/>
        <source>Deuces</source>
        <translation>Zweier</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1625"/>
        <source>Three</source>
        <translation>Drei</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1625"/>
        <source>Threes</source>
        <translation>Dreier</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1626"/>
        <source>Four</source>
        <translation>Vier</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1626"/>
        <source>Fours</source>
        <translation>Vierer</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1627"/>
        <source>Five</source>
        <translation>Fünf</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1627"/>
        <source>Fives</source>
        <translation>Fünfer</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1628"/>
        <source>Six</source>
        <translation>Sechs</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1628"/>
        <source>Sixes</source>
        <translation>Sechser</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1629"/>
        <source>Seven</source>
        <translation>Sieben</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1629"/>
        <source>Sevens</source>
        <translation>Siebener</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1630"/>
        <source>Eight</source>
        <translation>Acht</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1630"/>
        <source>Eights</source>
        <translation>Achter</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1631"/>
        <source>Nine</source>
        <translation>Neun</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1631"/>
        <source>Nines</source>
        <translation>Neuner</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1632"/>
        <source>Ten</source>
        <translation>Zehn</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1632"/>
        <source>Tens</source>
        <translation>Zehner</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1633"/>
        <source>Jack</source>
        <translation>Bube</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1633"/>
        <source>Jacks</source>
        <translation>Buben</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1634"/>
        <source>Queen</source>
        <translation>Dame</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1634"/>
        <source>Queens</source>
        <translation>Damen</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1635"/>
        <source>King</source>
        <translation>König</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1635"/>
        <source>Kings</source>
        <translation>Könige</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1636"/>
        <source>Ace</source>
        <translation>Ass</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1636"/>
        <source>Aces</source>
        <translation>Asse</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1659"/>
        <source>High Card</source>
        <translation>Höchste Karte</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1676"/>
        <location filename="../WTable.cpp" line="1711"/>
        <source>%1 high</source>
        <translation>%1 hoch</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1663"/>
        <source>One Pair</source>
        <translation>Ein Paar</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1667"/>
        <source>Two Pair</source>
        <translation>Zwei Paare</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1668"/>
        <location filename="../WTable.cpp" line="1694"/>
        <source>%1 and %2</source>
        <translation>%1 und %2</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1671"/>
        <source>Three Of A Kind</source>
        <translation>Drilling</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1675"/>
        <source>Straight</source>
        <translation>Straße</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1679"/>
        <source>Flush</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1693"/>
        <source>Full House</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1697"/>
        <source>Four Of A Kind</source>
        <translation>Vierling</translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1709"/>
        <source>Straight Flush</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../WTable.cpp" line="1704"/>
        <source>Royal Flush</source>
        <translation></translation>
    </message>
</context>
</TS>
